@@ -2,7 +2,7 @@
 /*
  * gsf-infile-msvba.h: 
  *
- * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2006 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -33,9 +33,15 @@ typedef struct _GsfInfileMSVBA GsfInfileMSVBA;
 #define GSF_INFILE_MSVBA(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), GSF_INFILE_MSVBA_TYPE, GsfInfileMSVBA))
 #define GSF_IS_INFILE_MSVBA(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), GSF_INFILE_MSVBA_TYPE))
 
-GType gsf_infile_msvba_get_type (void);
+GType gsf_infile_msvba_get_type      (void) G_GNUC_CONST;
+/* void  gsf_infile_msvba_register_type (GTypeModule *module); glib dynamic types are not thread safe */
 
-GsfInfile *gsf_infile_msvba_new (GsfInfile *source, GError **err);
+GsfInfile  *gsf_infile_msvba_new (GsfInfile *source, GError **err);
+GHashTable *gsf_infile_msvba_get_modules   (GsfInfileMSVBA const *vba_stream);
+GHashTable *gsf_infile_msvba_steal_modules (GsfInfileMSVBA       *vba_stream);
+
+/* Utility */
+GsfInfileMSVBA *gsf_input_find_vba (GsfInput *input, GError **err);
 
 G_END_DECLS
 
