@@ -2,8 +2,8 @@
 /*
  * gsf-input-iochannel.c: GIOChannel based input
  *
- * Copyright (C) 2003-2004 Rodrigo Moya (rodrigo@gnome-db.org)
- * Copyright (C) 2003-2004 Dom Lachowicz (cinamod@hotmail.com)
+ * Copyright (C) 2003-2006 Rodrigo Moya (rodrigo@gnome-db.org)
+ * Copyright (C) 2003-2006 Dom Lachowicz (cinamod@hotmail.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -22,14 +22,15 @@
 
 #include <gsf-config.h>
 #include <gsf-input-iochannel.h>
+#include <gsf-input-memory.h>
 
 /**
  * gsf_input_memory_new_from_iochannel :
  * @channel : a #GIOChannel.
  * @error : a #GError
  *
- * Returns a new #GsfInputMemory or NULL.
- */
+ * Returns: a new #GsfInputMemory or NULL.
+ **/
 GsfInput * 
 gsf_input_memory_new_from_iochannel (GIOChannel *channel,
 				     GError **err)
